* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Einkommen
* Mikrozensus Scientific Use File 2001

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink01.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=2001.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*--------------------------------------------   Persoenliches Nettoeinkommen   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF372 (1=225) (2=450) (3=800) (4=1200) (5=1600) (6=2000) (7=2350)
   (8=2750) (9=3250) (10=3750) (11=4250) (12=4750) (13=5250) (14=5750)
   (15=6250) (16=6750) (17=7250) (18=7750) (19=9000) (20=11000) (21=13500)
   (22=17500) (23=27500) (24=52500) (50=-2) (90=0) (99=-1) INTO einkp_1.
EXECUTE.

* Umrechnung in Euro (1 Euro=1,95583 DM).
IF einkp_1>=0 einkp_1=einkp_1/1.95583.
EXECUTE.


*------------------------------------   Persoenliches Nettoeinkommen, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkp_1>=0 einkp_2=einkp_1/0.874.
IF einkp_1<0 einkp_2=einkp_1.
EXECUTE.


*--------------------------------------------   Nettoeinkommen des Haushalts   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF539 (0=-2) (1=225) (2=450) (3=800) (4=1200) (5=1600) (6=2000)
   (7=2350) (8=2750) (9=3250) (10=3750) (11=4250) (12=4750) (13=5250)
   (14=5750) (15=6250) (16=6750) (17=7250) (18=7750) (19=9000) (20=11000)
   (21=13500) (22=17500) (23=27500) (24=52500) (50=-2) (99=-1) INTO einkh_1.
EXECUTE.

* Umrechnung in Euro (1 Euro = 1,95583 DM).
IF einkh_1>=0 einkh_1=einkh_1/1.95583.
EXECUTE.


*------------------------------------   Nettoeinkommen des Haushalts, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkh_1>=0 einkh_2=einkh_1/0.874.
IF einkh_1<0 einkh_2=einkh_1.
EXECUTE.


*---------------------------------------   Zahl der Einkommensbezieher im Haushalt   --------------------------------------.

* Hilfsvariable EF372r=1, wenn Person Einkommen bezieht, Landwirt oder mithelfender
  Familienangehoeriger ist, und EF372r=0, wenn Person kein Einkommen bezieht.
RECODE EF372 (1 THRU 50=1) (90=0) (99=SYSMIS) INTO EF372r.
EXECUTE.

SORT CASES BY hhnr.

AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr
   / ebezh=SUM(EF372r).
EXECUTE.

* Haushalte mit Personen ohne gueltige Angabe beim persoenlichen Einkommen.
RECODE ebezh (SYSMIS=-1) (ELSE=COPY).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF EF506=3 ebezh=-2.
EXECUTE.


*-------------------------------------------   Ueberwiegender Lebensunterhalt   -------------------------------------------.

RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5 THRU 8=4) INTO ueblu_1.
RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5=5) (6 THRU 8=6) INTO ueblu_2.
RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5=5) (6=6) (7=7) (8=8) INTO ueblu_3.
EXECUTE.


*---------------------------------------   Generierung temporaerer Hilfsvariablen   ---------------------------------------.

* werden spaeter zur Berechnung des Aequivalenzeinkommens und der
  relativen Einkommensposition benoetigt.

* West-Ost.
COMPUTE west=1.
IF EF1>=12 OR EF708=9 west=0.

* Stellung im Haushalt.
COMPUTE sth_t=EF507.
IF EF507=0 sth_t=99.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF372r.
EXECUTE.

