* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Einkommen
* Mikrozensus Scientific Use File 1973

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink73.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1973.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*--------------------------------------------   Persoenliches Nettoeinkommen   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF55 (0=-1) (1=112.5) (2=225) (3=375) (4=525) (5=700) (6=900)
   (7=1100) (8=1300) (9=1500) (10=1700) (11=1900) (12=2100) (13=2350)
   (14=2750) (15=4500) (50=-2) (99=0) INTO einkp_1.
EXECUTE.

* Umrechnung in Euro (1 Euro=1,95583 DM).
IF einkp_1>=0 einkp_1=einkp_1/1.95583.
EXECUTE.


*------------------------------------   Persoenliches Nettoeinkommen, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkp_1>=0 einkp_2=einkp_1/0.387.
IF einkp_1<0 einkp_2=einkp_1.
EXECUTE.


*--------------------------------------------   Nettoeinkommen des Haushalts   --------------------------------------------.

* in einzelnen Haushalten mit mehreren Bezugspersonen wird aelteste davon ausgewaehlt.
SORT CASES BY hhnr(A) EF23(A) EF66(D).

* Angabe des Haushaltseinkommens bei der Haushaltsbezugsperson wird auf alle uebrigen
  Haushaltsmitglieder uebertragen.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr 
   / ekh=FIRST(EF56).

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE ekh (0=-1) (1=112.5) (2=225) (3=375) (4=525) (5=700) (6=900)
   (7=1100) (8=1300) (9=1500) (10=1700) (11=1900) (12=2100) (13=2350)
   (14=2750) (15=4500) (50=-2) (99=-2) INTO einkh_1.
EXECUTE.

* Umrechnung in Euro (1 Euro = 1,95583 DM).
IF einkh_1>=0 einkh_1=einkh_1/1.95583.
EXECUTE.


*------------------------------------   Nettoeinkommen des Haushalts, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkh_1>=0 einkh_2=einkh_1/0.387.
IF einkh_1<0 einkh_2=einkh_1.
EXECUTE.


*---------------------------------------   Zahl der Einkommensbezieher im Haushalt   --------------------------------------.

* Hilfsvariable EF55r=1, wenn Person Einkommen bezieht, Landwirt oder mithelfender
  Familienangehoeriger ist, und EF55r=0, wenn Person kein Einkommen bezieht.
RECODE EF55 (0=SYSMIS) (1 THRU 50=1) (99=0) INTO EF55r.
EXECUTE.

AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr
   / ebezh=SUM(EF55r).
EXECUTE.

* Haushalte mit Personen ohne gueltige Angabe beim persoenlichen Einkommen.
RECODE ebezh (SYSMIS=-1) (ELSE=COPY).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF EF60=3 ebezh=-2.
EXECUTE.


*-------------------------------------------   Ueberwiegender Lebensunterhalt   -------------------------------------------.

RECODE EF48 (1=1) (2=2) (3=4) (4=3) (5 THRU 6=4) (7=1) INTO ueblu_1.
RECODE EF48 (1=1) (2=2) (3=4) (4=3) (5=5) (6=6) (7=1) INTO ueblu_2.
EXECUTE.


*---------------------------------------   Generierung temporaerer Hilfsvariablen   ---------------------------------------.

* werden spaeter zur Berechnung des Aequivalenzeinkommens und der
  relativen Einkommensposition benoetigt.

* West-Ost.
COMPUTE west=1.

* Stellung im Haushalt.
COMPUTE sth_t=EF23.
IF EF23=0 sth_t=99.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF55r  ekh.
EXECUTE.

