﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Haushalt, Familie und Lebensform
* Mikrozensus Scientific Use File 1980

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: fam80.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1980.

* Versionsnummer des Moduls 'Haushalt und Familie'.
COMPUTE vers_fam=5.


*-----------------------------------------------   Familienidentifikation   -----------------------------------------------.

* Laufende Nr.: Familie im Haushalt.
SORT CASES BY hhnr EF205.
IF hhnr~=LAG(hhnr) famnr=1.
IF $CASENUM=1 famnr=1.
IF hhnr=LAG(hhnr) AND EF205~=LAG(EF205) famnr=famnr+1.
LEAVE famnr.
EXECUTE.

* Laufende Nr.: Person in der Familie.
SORT CASES BY hhnr famnr EF62.
COMPUTE pfnr=1.
DO IF hhnr=LAG(hhnr) AND famnr=LAG(famnr).
+   COMPUTE pfnr=LAG(pfnr)+1.
END IF.
EXECUTE.


*------------------------------------------------------   Haushalt   ------------------------------------------------------.

* Stellung im Haushalt.
RECODE EF23 (0=-2) (3 THRU 7=3) (8=4) (ELSE=COPY) INTO sthh_1.
RECODE EF23 (0=-2) (3=3) (4 THRU 7=4) (8=5) (ELSE=COPY) INTO sthh_2.
RECODE EF23 (0=-2) (ELSE=COPY) INTO sthh_3.
EXECUTE.


* 1. Person im Privathaushalt.
RECODE sthh_1 (-2=99) (ELSE=COPY) INTO sthh_temp.
SORT CASES BY hhnr sthh_temp gesch (A) alter (D).
IF hhnr~=LAG(hhnr) ephh=1.
EXECUTE.
IF $CASENUM=1 ephh=1.
RECODE ephh (SYSMIS=0).

* Haushaltstyp.
RECODE EF63 (99=-2) (0=1) (1 THRU 4=2) (5=3) (6=5) (7=4) (8=6) (9=7) INTO hhtyp.

* Hilfsvariable h=1 fuer jede Person.
COMPUTE h=1.

* Hilfsvariable i=1, wenn Alter unter 3 Jahre (sonst i=0).
COMPUTE i=0.
IF (EF66<3) i=1.

* Hilfsvariable j=1, wenn Alter unter 15 Jahre (sonst j=0).
COMPUTE j=0.
IF (EF66<15) j=1.
IF (bpriv=2) h=0.
IF (bpriv=2) i=0.
IF (bpriv=2) j=0.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre im Haushalt.
SORT CASES BY hhnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hhanz=SUM (h)
   / hhk_1=SUM (i)
   / hhk_2=SUM (j).
IF (bpriv=2) hhanz=-2.
IF (bpriv=2) hhk_1=-2.
IF (bpriv=2) hhk_2=-2.


*-------------------------------------------------------   Familie   ------------------------------------------------------.

* Stellung in der Familie.
RECODE EF62 (0=-2) (ELSE=COPY) INTO stfam.

* Familientyp.
RECODE EF64 (0=-2) (4,7,9=3) (5,6,8=4) (ELSE=COPY) INTO famtyp_1.
RECODE EF64 (0=-2) (4=3) (5=4) (6=5) (7=6) (8=7) (9=8)
   (ELSE=COPY) INTO famtyp_2.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre in der Familie.
SORT CASES BY hhnr famnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr famnr
   / famanz=SUM (h)
   / famk_1=SUM (i)
   / famk_2=SUM (j).
IF (bpriv=2) famanz=-2.
IF (bpriv=2) famk_1=-2.
IF (bpriv=2) famk_2=-2.


*-------------------------------------------------   Eheschliessungsjahr   ------------------------------------------------.

COMPUTE ehej=EF22+1900.
IF (EF22=2) ehej=1907.
IF (EF22=8) ehej=1909.
IF (EF22=90 OR EF22=99) ehej=-1.
IF (EF21~=2) ehej=-2.
RECODE ehej (1907=1909).
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES sthh_temp h i j.
EXECUTE.

