﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Haushalt, Familie und Lebensform
* Mikrozensus Scientific Use File 1996

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: fam96.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1996.

* Versionsnummer des Moduls 'Haushalt und Familie'.
COMPUTE vers_fam=5.


*-----------------------------------------------   Familienidentifikation   -----------------------------------------------.

* Laufende Nr.: Familie im Haushalt.
SORT CASES BY hhnr EF28.
IF hhnr~=LAG(hhnr) famnr=1.
IF $CASENUM=1 famnr=1.
IF hhnr=LAG(hhnr) AND EF28~=LAG(EF28) famnr=famnr+1.
LEAVE famnr.
EXECUTE.

* Laufende Nr.: Person in der Familie.
SORT CASES BY hhnr famnr EF509.
COMPUTE pfnr=1.
DO IF hhnr=LAG(hhnr) AND famnr=LAG(famnr).
+   COMPUTE pfnr=LAG(pfnr)+1.
END IF.
EXECUTE.


*------------------------------------------------------   Haushalt   ------------------------------------------------------.

* Stellung im Haushalt.
RECODE EF507 (0=-2) (3 THRU 7=3) (9=4) (ELSE=COPY) INTO sthh_1.
RECODE EF507 (0=-2) (4 THRU 7=4) (9=5) (ELSE=COPY) INTO sthh_2.
RECODE EF507 (0=-2) (9=8) (ELSE=COPY) INTO sthh_3.
EXECUTE.

* 1. Person im Privathaushalt.
RECODE sthh_1 (-2=99) (ELSE=COPY) INTO sthh_temp.
SORT CASES BY hhnr sthh_temp gesch (A) alter (D).
IF hhnr~=LAG(hhnr) ephh=1.
EXECUTE.
IF $CASENUM=1 ephh=1.
RECODE ephh (SYSMIS=0).

* Haushaltstyp.
RECODE EF541 (9=-2) (0=1) (1=2) (2=3) (3,4=4) (ELSE=COPY) INTO hhtyp.

* Hilfsvariable h=1 fuer jede Person.
COMPUTE h=1.

* Hilfsvariable i=1, wenn Alter unter 3 Jahre (sonst i=0).
COMPUTE i=0.
IF (EF30<3) i=1.

* Hilfsvariable j=1, wenn Alter unter 15 Jahre (sonst j=0).
COMPUTE j=0.
IF (EF30<15) j=1.
IF (bpriv=2) h=0.
IF (bpriv=2) i=0.
IF (bpriv=2) j=0.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre im Haushalt.
SORT CASES BY hhnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hhanz=SUM (h)
   / hhk_1=SUM (i)
   / hhk_2=SUM (j).
IF (bpriv=2) hhanz=-2.
IF (bpriv=2) hhk_1=-2.
IF (bpriv=2) hhk_2=-2.


*-------------------------------------------------------   Familie   ------------------------------------------------------.

* Stellung in der Familie.
RECODE EF509 (0=-2) (ELSE=COPY) INTO stfam.

* Familientyp.
RECODE EF575 (0=-2) (4,7,9=3) (5,6,8=4) (ELSE=COPY) INTO famtyp_1.
RECODE EF575 (0=-2) (4=3) (5=4) (6=5) (7=6) (8=7) (9=8)
   (ELSE=COPY) INTO famtyp_2.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre in der Familie.
SORT CASES BY hhnr famnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr famnr
   / famanz=SUM (h)
   / famk_1=SUM (i)
   / famk_2=SUM (j).
IF (bpriv=2) famanz=-2.
IF (bpriv=2) famk_1=-2.
IF (bpriv=2) famk_2=-2.


*-------------------------------------------------   Eheschliessungsjahr   ------------------------------------------------.

COMPUTE ehej=EF36.
IF (EF36=9999) ehej=-1.
IF (EF35~=2) ehej=-2.


*------------------------------------------------   Lebensgemeinschaften   ------------------------------------------------.

* Laufende Nr.: Lebensgemeinschaft im Haushalt.
SORT CASES BY hhnr EF643.
IF hhnr~=LAG(hhnr) lgnr=1.
IF $CASENUM=1 lgnr=1.
IF hhnr=LAG(hhnr) AND EF643~=LAG(EF643) lgnr=lgnr+1.
LEAVE lgnr.
EXECUTE.

* Laufende Nr.: Person in der Lebensgemeinschaft.
SORT CASES BY hhnr lgnr EF514.
COMPUTE plgnr=1.
DO IF hhnr=LAG(hhnr) AND lgnr=LAG(lgnr).
+   COMPUTE plgnr=LAG(plgnr)+1.
END IF.
EXECUTE.

* Stellung in der Lebensgemeinschaft.
RECODE EF514 (0=-2) (ELSE=COPY) INTO stlg.

* Typ der Lebensgemeinschaft.
RECODE EF627 (0=-2) (1,6=1) (2,7=2) (8,9=3) (3,4,5=4) INTO lgtyp.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre in der Lebensgemeinschaft.
SORT CASES BY hhnr lgnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr lgnr
   / lganz=SUM (h)
   / lgk_1=SUM (i)
   / lgk_2=SUM (j).
IF (bpriv=2) lganz=-2.
IF (bpriv=2) lgk_1=-2.
IF (bpriv=2) lgk_2=-2.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES sthh_temp h i j.
EXECUTE.

