* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Methodische Variablen
* Mikrozensus Scientific Use File 1980

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: methvar80.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=1980.

* Versionsnummer des Moduls 'Methodische Variablen'.
COMPUTE vers_met=5.


*---------------------------------------------------------   ID   ---------------------------------------------------------.

* Identifikationsnummer, fortlaufend nach Reihenfolge im Ausgangsdatensatz.
COMPUTE idnr=(1980000000+$CASENUM).
EXECUTE.


*----------------------------------------------   Zweite Erwerbstaetigkeit   ----------------------------------------------.

* Ausschluss von Duplikaten mit Angaben zur zweiten Erwerbstaetigkeit.
SELECT IF EF38=0 OR EF38=1.
EXECUTE.


*----------------------------------------------   Haushaltsidentifikation   -----------------------------------------------.

* Haushaltsnummer, fortlaufend.
SORT CASES BY EF1 EF5 EF203.
IF $CASENUM=1 hhnr=1.
IF EF1~=lag(EF1) OR EF5~=lag(EF5) OR EF203~=lag(EF203) hhnr=hhnr+1.
LEAVE hhnr.
EXECUTE.


*------------------------------------   Anpassung an die Bevoelkerungsfortschreibung   ------------------------------------.

*--- Identifikation von Duplikaten ueber Abgleich von personenbezogenen Variablen ---.

* in Faellen, in denen die Duplikate in EF4 ausgewiesen sind, werden die Daten so
  sortiert, dass die Duplikate den Originalfaellen unmittelbar folgen.
RECODE EF4 (1=2) (ELSE=1) INTO EF4r.
SORT CASES BY hhnr EF18 EF20 EF19 EF66 EF21 EF22 EF23 EF17 EF27 EF28 EF29
   EF30 EF33 EF34 EF35 EF36 EF37 EF39 EF40 EF41 EF42 EF43 EF44 EF45 EF48 EF49
   EF50 EF51 EF52 EF53 EF54 EF55 EF62 EF70 EF71 EF72 EF74 EF78 EF79 EF80 EF85
   EF86 EF88 EF89 EF4r.
COMPUTE p=1.

* Markierung der Personen mit identischen Auspraegungen in allen relevanten Variablen
  (sum gibt deren Anzahl wieder).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr EF18 EF20 EF19 EF66 EF21 EF22 EF23 EF17 EF27 EF28 EF29
   EF30 EF33 EF34 EF35 EF36 EF37 EF39 EF40 EF41 EF42 EF43 EF44 EF45 EF48 EF49
   EF50 EF51 EF52 EF53 EF54 EF55 EF62 EF70 EF71 EF72 EF74 EF78 EF79 EF80 EF85
   EF86 EF88 EF89
   / sum=SUM(p).
EXECUTE.

* jeweils erste Person wird als Originalfall markiert.
IF (hhnr~=LAG(hhnr) OR ((hhnr=LAG(hhnr) AND (EF18~=LAG(EF18) OR EF20~=LAG(EF20)
   OR EF19~=LAG(EF19) OR EF66~=LAG(EF66) OR EF21~=LAG(EF21) OR EF22~=LAG(EF22)
   OR EF23~=LAG(EF23) OR EF17~=LAG(EF17) OR EF27~=LAG(EF27) OR EF28~=LAG(EF28)
   OR EF29~=LAG(EF29) OR EF30~=LAG(EF30) OR EF33~=LAG(EF33) OR EF34~=LAG(EF34)
   OR EF35~=LAG(EF35) OR EF36~=LAG(EF36) OR EF37~=LAG(EF37) OR EF39~=LAG(EF39)
   OR EF40~=LAG(EF40) OR EF41~=LAG(EF41) OR EF42~=LAG(EF42) OR EF43~=LAG(EF43)
   OR EF44~=LAG(EF44) OR EF45~=LAG(EF45) OR EF48~=LAG(EF48) OR EF49~=LAG(EF49)
   OR EF50~=LAG(EF50) OR EF51~=LAG(EF51) OR EF52~=LAG(EF52) OR EF53~=LAG(EF53)
   OR EF54~=LAG(EF54) OR EF55~=LAG(EF55) OR EF62~=LAG(EF62) OR EF70~=LAG(EF70)
   OR EF71~=LAG(EF71) OR EF72~=LAG(EF72) OR EF74~=LAG(EF74) OR EF78~=LAG(EF78)
   OR EF79~=LAG(EF79) OR EF80~=LAG(EF80) OR EF85~=LAG(EF85) OR EF86~=LAG(EF86)
   OR EF88~=LAG(EF88) OR EF89~=LAG(EF89)))))
   AND sum>1 master=1.

* alle weiteren Personen werden als Duplikat markiert.
IF sum>1 AND SYSMIS(master) master=2.
EXECUTE.

* Korrektur fuer den ersten Fall im ersten Haushalt.
IF $CASENUM=1 master=1.
EXECUTE.



*----------------------------------------------   Ausschluss der Duplikate   ----------------------------------------------.

SELECT IF SYSMIS(master) OR master=1.
EXECUTE.


*---------------------------------------   Gewichtungs- und Hochrechnungsfaktoren   ---------------------------------------.

* Personengewichtungsfaktor
  (Originalfaelle werden mit dem Faktor ihrer Vervielfachung gewichtet; zu streichende Faelle
  werden mit 0, wenn sie zusaetzlich vervielfacht wurden mit sum-1 gewichtet; alle uebrigen Faelle
  werden mit 1 gewichtet).
COMPUTE pge=1.
IF master=1 pge=sum.
IF EF4=2 AND SYSMIS(master) pge=0.
IF EF4=2 AND master=1 pge=sum-1.
EXECUTE.

* Haushaltsgewichtungsfaktor
  (arithmetisches Mittel der Personengewichtungsfaktoren aller Haushaltsmitglieder).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hge=MEAN(pge).
EXECUTE.

* Personengewichtungs- und Hochrechnungsfaktor.
COMPUTE pgeh=pge*100/0.7.
EXECUTE.

* Haushaltsgewichtungs- und Hochrechnungsfaktor.
COMPUTE hgeh=hge*100/0.7.
EXECUTE.


*------------------------------------   Stichprobenkennzeichnung und Erhebungsmodus   -------------------------------------.

* nicht relevant / nicht ausgewiesen.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF4r master p sum.
EXECUTE.

