* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Methodische Variablen
* Mikrozensus Scientific Use File 1982

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: methvar82.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=1982.

* Versionsnummer des Moduls 'Methodische Variablen'.
COMPUTE vers_met=5.


*---------------------------------------------------------   ID   ---------------------------------------------------------.

* Identifikationsnummer, fortlaufend nach Reihenfolge im Ausgangsdatensatz.
COMPUTE idnr=(1982000000+$CASENUM).
EXECUTE.


*----------------------------------------------   Zweite Erwerbstaetigkeit   ----------------------------------------------.

* Ausschluss von Duplikaten mit Angaben zur zweiten Erwerbstaetigkeit.
SELECT IF EF38=0 OR EF38=1.
EXECUTE.


*----------------------------------------------   Haushaltsidentifikation   -----------------------------------------------.

* Haushaltsnummer, fortlaufend.
SORT CASES BY EF1 EF5 EF203.
IF $CASENUM=1 hhnr=1.
IF EF1~=lag(EF1) OR EF5~=lag(EF5) OR EF203~=lag(EF203) hhnr=hhnr+1.
LEAVE hhnr.
EXECUTE.


*------------------------------------   Anpassung an die Bevoelkerungsfortschreibung   ------------------------------------.

*--- gedoppelte Soldaten ---.

RECODE EF76 (3=1) (ELSE=0) INTO sld.
EXECUTE.


*--- sonstige Dopplungen ---.

* Daten werden so sortiert, dass die Originalfaelle den jeweilgen Duplikaten unmittelbar
  folgen (unter Beruecksichtigung, dass Sort-Befehl maximal 64 Variablen verarbeiten kann).
RECODE EF76 (1=1) (ELSE=2) INTO EF76r.
SORT CASES BY hhnr EF17 EF18 EF19 EF20 EF21 EF22 EF23 EF24 EF25 EF26 EF27
   EF28 EF29 EF30 EF31 EF32 EF33 EF34 EF35 EF36 EF37 EF38 EF39 EF41 EF42 EF43
   EF44 EF45 EF46 EF47 EF48 EF49 EF50 EF51 EF52 EF53 EF54 EF55 EF57 EF58 EF60
   EF61 EF62 EF64 EF65 EF66 EF67 EF68 EF70 EF71 EF72 EF74 EF78 EF79 EF80 EF82
   EF83 EF84 EF85 EF86 EF87 EF88 EF76r.

* Markierung der Originalfaelle.
IF hhnr=LAG(hhnr) AND LAG(EF76r)=1 master=1.
EXECUTE.


*----------------------------------------------   Ausschluss der Duplikate   ----------------------------------------------.

* nur Duplikate, bei denen es sich um Soldaten handelt (EF76=3), verbleiben im Datensatz
  (Originalfaelle sind nicht identifizerbar).

SELECT IF EF76~=1.
EXECUTE.


*---------------------------------------   Gewichtungs- und Hochrechnungsfaktoren   ---------------------------------------.

* Personengewichtungsfaktor
  (Originalfaelle werden mit dem Faktor 2, zu streichende Faelle mit dem Faktor 0
  und alle uebrigen Faelle mit dem Faktor 1 gewichtet).
COMPUTE pge=1.
IF master=1 pge=2.
IF (EF76=2 OR EF76=4) pge=0.
EXECUTE.

* Haushaltsgewichtungsfaktor
  (arithmetisches Mittel der Personengewichtungsfaktoren aller Haushaltsmitglieder).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hge=MEAN(pge).
EXECUTE.

* Personengewichtungs- und Hochrechnungsfaktor.
COMPUTE pgeh=pge*100/0.7.
EXECUTE.

* Haushaltsgewichtungs- und Hochrechnungsfaktor.
COMPUTE hgeh=hge*100/0.7.
EXECUTE.


*------------------------------------   Stichprobenkennzeichnung und Erhebungsmodus   -------------------------------------.

* nicht relevant / nicht ausgewiesen.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF76r master.
EXECUTE.

